@@ -12,7 +12,7 @@ use warnings;
 use utf8;
 use open qw(:std :utf8);
 package App::SpreadRevolutionaryDate;
-$App::SpreadRevolutionaryDate::VERSION = '0.05';
+$App::SpreadRevolutionaryDate::VERSION = '0.06';
 # ABSTRACT: Spread date and time from Revolutionary (Republican) Calendar on Twitter, Mastodon and Freenode.
 
 use App::SpreadRevolutionaryDate::Config;
@@ -72,16 +72,23 @@ sub spread {
   my $no_run = shift || 1;
   $no_run = !$no_run;
 
+  # As of DateTime::Calendar::FrenchRevolutionary 0.14
+  # locale is limited to 'en' or 'fr', defaults to 'fr'
+  my $locale = $self->{config}->locale || 'fr';
+  $locale = 'fr' unless $locale eq 'en';
+
   my $now = $self->{config}->acab ?
       DateTime->today->set(hour => 3, minute => 8, second => 56)
     : DateTime->now;
-  my $msg = DateTime::Calendar::FrenchRevolutionary->from_object(object => $now)->strftime("Nous sommes le %A, %d %B de l'An %EY (%Y) de la Révolution, %Ej, il est %T!");
+  my $revolutionary = DateTime::Calendar::FrenchRevolutionary->from_object(object => $now, locale => $locale);
+  my $msg = $locale eq 'fr' ? $revolutionary->strftime("Nous sommes le %A, %d %B de l'An %EY (%Y) de la Révolution, %Ej, il est %T!") : $revolutionary->strftime("We are %A, %d %B of Revolution Year %EY (%Y), %Ej, it is %T!");
 
-  $self->{twitter}->spread($msg) if $self->{twitter};
-  $self->{mastodon}->spread($msg) if $self->{mastodon};
-  $self->{freenode}->spread($msg, $no_run) if $self->{freenode};
+  $self->{twitter}->spread($msg) if $self->{config}->twitter;
+  $self->{mastodon}->spread($msg) if $self->{config}->mastodon;
+  $self->{freenode}->spread($msg, $no_run) if $self->{config}->freenode;
 }
 
+
 1;
 
 __END__
@@ -96,7 +103,7 @@ App::SpreadRevolutionaryDate - Spread date and time from Revolutionary (Republic
 
 =head1 VERSION
 
-version 0.05
+version 0.06
 
 =head1 METHODS
 
@@ -108,6 +115,24 @@ Constructor class method. Takes one optional argument: C<$filename> which should
 
 Spreads calendar date to configured targets. Takes one optional boolean argument, if true (default) authentication and spreading to Freenode is performed, otherwise, you've got to run C<use POE; POE::Kernel-E<gt>run();> to do so. This is only used for testing, when multiple bots are needed. You can safely leave this optional argument unset.
 
+=head1 SEE ALSO
+
+=over
+
+=item L<spread-revolutionary-date|https://metacpan.org/pod/distribution/App-SpreadRevolutionaryDate/bin/spread-revolutionary-date>
+
+=item L<App::SpreadRevolutionaryDate::Config>
+
+=item L<App::SpreadRevolutionaryDate::Twitter>
+
+=item L<App::SpreadRevolutionaryDate::Mastodon>
+
+=item L<App::SpreadRevolutionaryDate::Freenode>
+
+=item L<App::SpreadRevolutionaryDate::Freenode::Bot>
+
+=back
+
 =head1 AUTHOR
 
 Gérald Sédrati-Dinet <gibus@cpan.org>
