@@ -12,33 +12,36 @@ use warnings;
 use utf8;
 use open qw(:std :utf8);
 package App::SpreadRevolutionaryDate::Config;
-$App::SpreadRevolutionaryDate::Config::VERSION = '0.05';
+$App::SpreadRevolutionaryDate::Config::VERSION = '0.06';
 # ABSTRACT: Subclass of L<App::SpreadRevolutionaryDate> to handle configuration file and command line arguments.
 
 use AppConfig qw(:argcount);
+use File::HomeDir;
+use namespace::clean;
 use parent 'AppConfig';
 
 
 sub new {
   my $class = shift;
   return AppConfig::new($class,
-    'acab' => {ARGCOUNT => ARGCOUNT_NONE},
-    'test' => {ARGCOUNT => ARGCOUNT_NONE},
-    'twitter' => {ARGCOUNT => ARGCOUNT_NONE},
-    'mastodon' => {ARGCOUNT => ARGCOUNT_NONE},
-    'freenode' => {ARGCOUNT => ARGCOUNT_NONE},
-    'twitter_consumer_key' => {ARGCOUNT => ARGCOUNT_ONE},
-    'twitter_consumer_secret' => {ARGCOUNT => ARGCOUNT_ONE},
-    'twitter_access_token' => {ARGCOUNT => ARGCOUNT_ONE},
-    'twitter_access_token_secret' => {ARGCOUNT => ARGCOUNT_ONE},
-    'mastodon_instance' => {ARGCOUNT => ARGCOUNT_ONE},
-    'mastodon_client_id' => {ARGCOUNT => ARGCOUNT_ONE},
-    'mastodon_client_secret' => {ARGCOUNT => ARGCOUNT_ONE},
-    'mastodon_access_token' => {ARGCOUNT => ARGCOUNT_ONE},
-    'freenode_nickname' => {ARGCOUNT => ARGCOUNT_ONE},
-    'freenode_password' => {ARGCOUNT => ARGCOUNT_ONE},
-    'freenode_test_channels' => {ARGCOUNT => ARGCOUNT_LIST},
-    'freenode_channels' => {ARGCOUNT => ARGCOUNT_LIST},
+    'acab' => {ARGCOUNT => ARGCOUNT_NONE, ALIAS => 'a'},
+    'test' => {ARGCOUNT => ARGCOUNT_NONE, ALIAS => 'no|n'},
+    'locale' => {ARGCOUNT => ARGCOUNT_ONE, ALIAS => 'l'},
+    'twitter' => {ARGCOUNT => ARGCOUNT_NONE, ALIAS => 't'},
+    'mastodon' => {ARGCOUNT => ARGCOUNT_NONE, ALIAS => 'm'},
+    'freenode' => {ARGCOUNT => ARGCOUNT_NONE, ALIAS => 'f'},
+    'twitter_consumer_key' => {ARGCOUNT => ARGCOUNT_ONE, ALIAS => 'tck'},
+    'twitter_consumer_secret' => {ARGCOUNT => ARGCOUNT_ONE, ALIAS => 'tcs'},
+    'twitter_access_token' => {ARGCOUNT => ARGCOUNT_ONE, ALIAS => 'tat'},
+    'twitter_access_token_secret' => {ARGCOUNT => ARGCOUNT_ONE, ALIAS => 'tats'},
+    'mastodon_instance' => {ARGCOUNT => ARGCOUNT_ONE, ALIAS => 'mi'},
+    'mastodon_client_id' => {ARGCOUNT => ARGCOUNT_ONE, ALIAS => 'mci'},
+    'mastodon_client_secret' => {ARGCOUNT => ARGCOUNT_ONE, ALIAS => 'mcs'},
+    'mastodon_access_token' => {ARGCOUNT => ARGCOUNT_ONE, ALIAS => 'mat'},
+    'freenode_nickname' => {ARGCOUNT => ARGCOUNT_ONE, ALIAS => 'fn'},
+    'freenode_password' => {ARGCOUNT => ARGCOUNT_ONE, ALIAS => 'fp'},
+    'freenode_test_channels' => {ARGCOUNT => ARGCOUNT_LIST, ALIAS => 'ftc'},
+    'freenode_channels' => {ARGCOUNT => ARGCOUNT_LIST, ALIAS => 'fc'},
   );
 }
 
@@ -47,8 +50,8 @@ sub parse_file {
   my $self = shift;
   my $filename = shift;
   foreach my $default_path (
-                $ENV{HOME} . '/.config/spread-revolutionary-date/spread-revolutionary-date.conf',
-                $ENV{HOME} . '/.spread-revolutionary-date.conf') {
+                File::HomeDir->my_home . '/.config/spread-revolutionary-date/spread-revolutionary-date.conf',
+                File::HomeDir->my_home . '/.spread-revolutionary-date.conf') {
     $filename = $default_path if (!$filename && -f $default_path)
   }
   $self->file($filename);
@@ -87,6 +90,7 @@ sub check_freenode {
               || !!$self->freenode_channels);
 }
 
+
 1;
 
 __END__
@@ -101,7 +105,7 @@ App::SpreadRevolutionaryDate::Config - Subclass of L<App::SpreadRevolutionaryDat
 
 =head1 VERSION
 
-version 0.05
+version 0.06
 
 =head1 METHODS
 
@@ -129,6 +133,24 @@ Checks whether Mastodon configuration options are set to authenticate on Mastodo
 
 Checks whether Freenode configuration options are set to authenticate on Freenode. Takes no argument.
 
+=head1 SEE ALSO
+
+=over
+
+=item L<spread-revolutionary-date|https://metacpan.org/pod/distribution/App-SpreadRevolutionaryDate/bin/spread-revolutionary-date>
+
+=item L<App::SpreadRevolutionaryDate>
+
+=item L<App::SpreadRevolutionaryDate::Twitter>
+
+=item L<App::SpreadRevolutionaryDate::Mastodon>
+
+=item L<App::SpreadRevolutionaryDate::Freenode>
+
+=item L<App::SpreadRevolutionaryDate::Freenode::Bot>
+
+=back
+
 =head1 AUTHOR
 
 Gérald Sédrati-Dinet <gibus@cpan.org>
